Crate use_db_query

Crate use_db_query 

use-db-query

Query labels, kinds, modes, timeout, pagination, cursor, sorting, filter, and projection vocabulary.

This crate is part of the use-database facade workspace. It provides small, engine-neutral vocabulary types and metadata containers. It does not connect to databases, execute queries, run migrations, parse SQL, or model engine-specific behavior.

Example

use use_db_query::{PageRequest, SortDirection};

let page = PageRequest::new(1, 50);
assert_eq!(page.page(), 1);
assert_eq!(SortDirection::Ascending.as_str(), "ascending");

Query vocabulary primitives for RustUse.

Structs

Cursor
Limit
Limit count metadata.
Offset
Offset count metadata.
PageRequest
Page request metadata.
Projection
Projection metadata.
QueryLabel
QueryTimeout
Query timeout in milliseconds.
SortKey

Enums

FilterOperator
Filter operator vocabulary.
QueryError
Error returned by query vocabulary constructors.
QueryKind
Broad query kind.
QueryMode
Query mode metadata.
SortDirection
Sort direction metadata.